dengfengjiang77 commented on issue #16674:
URL: https://github.com/apache/lucene/issues/16674#issuecomment-6000600328

   I checked the proposal from @kaivalnp , it does work well from speed level, 
and we can calculate the centroid value in different cases( no delete/ delete 
<= 50% / delete > 50%) which reduce the vector bytes read, the demo test showed 
that the improvement can be happened, I will open a PR to address the solution. 
   PS : to answer @msokolov question, the whole force merge will take 10-12s, 
and this change will increase around 10~20ms, and by bytes read, the vectors 
reads will reduce from 460MB to 4.6Mb taking 1% deletes for example.


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: [email protected]

For queries about this service, please contact Infrastructure at:
[email protected]


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to